summaryrefslogtreecommitdiffstats
path: root/xlators/mgmt/glusterd/src/glusterd-op-sm.c
diff options
context:
space:
mode:
Diffstat (limited to 'xlators/mgmt/glusterd/src/glusterd-op-sm.c')
-rw-r--r--xlators/mgmt/glusterd/src/glusterd-op-sm.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/xlators/mgmt/glusterd/src/glusterd-op-sm.c b/xlators/mgmt/glusterd/src/glusterd-op-sm.c
index a5d0477e00b..b461edba106 100644
--- a/xlators/mgmt/glusterd/src/glusterd-op-sm.c
+++ b/xlators/mgmt/glusterd/src/glusterd-op-sm.c
@@ -2068,12 +2068,12 @@ _delete_reconfig_opt (dict_t *this, char *key, data_t *value, void *data)
GF_ASSERT (data);
is_force = (int32_t*)data;
/* Keys which has the flag OPT_FLAG_NEVER_RESET
* should not be deleted
*/
if (_gf_true == glusterd_check_voloption_flags (key,
- OPT_FLAG_NEVER_RESET)) {
+ VOLOPT_FLAG_NEVER_RESET)) {
if (*is_force != 1)
*is_force = *is_force | GD_OP_PROTECTED;
goto out;
@@ -2081,7 +2081,7 @@ _delete_reconfig_opt (dict_t *this, char *key, data_t *value, void *data)
if (*is_force != 1) {
if (_gf_true == glusterd_check_voloption_flags (key,
- OPT_FLAG_FORCE)) {
+ VOLOPT_FLAG_FORCE)) {
/* indicate to caller that we don't set the option
* due to being protected
*/
@@ -2068,12 +2068,12 @@ _delete_reconfig_opt (dict_t *this, char *key, data_t *value, void *data)
GF_ASSERT (data);
is_force = (int32_t*)data;
- /* Keys which has the flag OPT_FLAG_NEVER_RESET
+ /* Keys which has the flag VOLOPT_FLAG_NEVER_RESET
* should not be deleted
*/